( cd sbin ; rm -rf mount.smbfs )
( cd sbin ; ln -sf /usr/bin/smbmount mount.smbfs )
#%% begin initialize samba-3.0.37-i586-P4
chk=`grep swat /etc/services`
if [ "$chk.x" = ".x" ]; then
  echo 'swat		901/tcp' >> /etc/services
fi

chk=`grep swat /etc/inetd.conf`
if [ "$chk.x" = ".x" ]; then
  echo 'swat	stream tcp nowait root /usr/sbin/tcpd /usr/sbin/swat' >> /etc/inetd.conf
fi

kill -HUP `pidof inetd`

#%% end
